.. KM3Pipe documentation master file, created by
   sphinx-quickstart on Sat Oct  4 19:16:43 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: version.txt

.. image:: https://travis-ci.org/tamasgal/km3pipe.svg?branch=develop
    :target: https://travis-ci.org/tamasgal/km3pipe

.. image:: https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat
    :target: http://km3pipe.readthedocs.io/en/latest/

.. include:: summary.rst

.. toctree::
    :hidden:
    :titlesonly:

    self

.. toctree::
    :maxdepth: 2

    install
    user_guide
    examples
    api
    contribute
    changelog

* :ref:`genindex`
